Index: /trunk/src/VBox/Frontends/VirtualBox/Makefile.kmk
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/Makefile.kmk	(revision 75423)
+++ /trunk/src/VBox/Frontends/VirtualBox/Makefile.kmk	(revision 75424)
@@ -809,7 +809,7 @@
 	src/logviewer/UIVMLogViewerDialog.h \
 	src/logviewer/UIVMLogViewerFilterPanel.h \
+	src/logviewer/UIVMLogViewerOptionsPanel.h \
 	src/logviewer/UIVMLogViewerPanel.h \
 	src/logviewer/UIVMLogViewerSearchPanel.h \
-	src/logviewer/UIVMLogViewerSettingsPanel.h \
 	src/logviewer/UIVMLogViewerTextEdit.h \
 	src/logviewer/UIVMLogViewerWidget.h \
@@ -1100,7 +1100,7 @@
 	src/logviewer/UIVMLogViewerDialog.h \
 	src/logviewer/UIVMLogViewerFilterPanel.h \
+	src/logviewer/UIVMLogViewerOptionsPanel.h \
 	src/logviewer/UIVMLogViewerPanel.h \
 	src/logviewer/UIVMLogViewerSearchPanel.h \
-	src/logviewer/UIVMLogViewerSettingsPanel.h \
 	src/logviewer/UIVMLogViewerTextEdit.h \
 	src/logviewer/UIVMLogViewerWidget.h \
@@ -1521,7 +1521,7 @@
 	src/logviewer/UIVMLogViewerDialog.cpp \
 	src/logviewer/UIVMLogViewerFilterPanel.cpp \
+	src/logviewer/UIVMLogViewerOptionsPanel.cpp \
 	src/logviewer/UIVMLogViewerPanel.cpp \
 	src/logviewer/UIVMLogViewerSearchPanel.cpp \
-	src/logviewer/UIVMLogViewerSettingsPanel.cpp \
 	src/logviewer/UIVMLogViewerTextEdit.cpp \
 	src/logviewer/UIVMLogViewerWidget.cpp \
@@ -1864,7 +1864,7 @@
 	src/logviewer/UIVMLogViewerDialog.cpp \
 	src/logviewer/UIVMLogViewerFilterPanel.cpp \
+	src/logviewer/UIVMLogViewerOptionsPanel.cpp \
 	src/logviewer/UIVMLogViewerPanel.cpp \
 	src/logviewer/UIVMLogViewerSearchPanel.cpp \
-	src/logviewer/UIVMLogViewerSettingsPanel.cpp \
 	src/logviewer/UIVMLogViewerTextEdit.cpp \
 	src/logviewer/UIVMLogViewerWidget.cpp \
Index: /trunk/src/VBox/Frontends/VirtualBox/VirtualBox1.qrc
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/VirtualBox1.qrc	(revision 75423)
+++ /trunk/src/VBox/Frontends/VirtualBox/VirtualBox1.qrc	(revision 75424)
@@ -372,6 +372,6 @@
         <file alias="log_viewer_search_backward_16px.png">images/log_viewer_search_backward_16px.png</file>
         <file alias="log_viewer_search_forward_16px.png">images/log_viewer_search_forward_16px.png</file>
-        <file alias="log_viewer_settings_32px.png">images/log_viewer_settings_32px.png</file>
-        <file alias="log_viewer_settings_disabled_32px.png">images/log_viewer_settings_disabled_32px.png</file>
+        <file alias="log_viewer_options_32px.png">images/log_viewer_options_32px.png</file>
+        <file alias="log_viewer_options_disabled_32px.png">images/log_viewer_options_disabled_32px.png</file>
         <file alias="machine_16px.png">images/machine_16px.png</file>
         <file alias="machine_24px.png">images/machine_24px.png</file>
Index: /trunk/src/VBox/Frontends/VirtualBox/VirtualBox1_x2.qrc
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/VirtualBox1_x2.qrc	(revision 75423)
+++ /trunk/src/VBox/Frontends/VirtualBox/VirtualBox1_x2.qrc	(revision 75424)
@@ -368,6 +368,6 @@
         <file alias="log_viewer_search_backward_16px_x2.png">images/x2/log_viewer_search_backward_16px_x2.png</file>
         <file alias="log_viewer_search_forward_16px_x2.png">images/x2/log_viewer_search_forward_16px_x2.png</file>
-        <file alias="log_viewer_settings_32px_x2.png">images/x2/log_viewer_settings_32px_x2.png</file>
-        <file alias="log_viewer_settings_disabled_32px_x2.png">images/x2/log_viewer_settings_disabled_32px_x2.png</file>
+        <file alias="log_viewer_options_32px_x2.png">images/x2/log_viewer_options_32px_x2.png</file>
+        <file alias="log_viewer_options_disabled_32px_x2.png">images/x2/log_viewer_options_disabled_32px_x2.png</file>
         <file alias="machine_16px_x2.png">images/x2/machine_16px_x2.png</file>
         <file alias="machine_24px_x2.png">images/x2/machine_24px_x2.png</file>
Index: /trunk/src/VBox/Frontends/VirtualBox/VirtualBox1_x3.qrc
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/VirtualBox1_x3.qrc	(revision 75423)
+++ /trunk/src/VBox/Frontends/VirtualBox/VirtualBox1_x3.qrc	(revision 75424)
@@ -251,6 +251,6 @@
         <file alias="log_viewer_search_backward_16px_x3.png">images/x3/log_viewer_search_backward_16px_x3.png</file>
         <file alias="log_viewer_search_forward_16px_x3.png">images/x3/log_viewer_search_forward_16px_x3.png</file>
-        <file alias="log_viewer_settings_32px_x3.png">images/x3/log_viewer_settings_32px_x3.png</file>
-        <file alias="log_viewer_settings_disabled_32px_x3.png">images/x3/log_viewer_settings_disabled_32px_x3.png</file>
+        <file alias="log_viewer_options_32px_x3.png">images/x3/log_viewer_options_32px_x3.png</file>
+        <file alias="log_viewer_options_disabled_32px_x3.png">images/x3/log_viewer_options_disabled_32px_x3.png</file>
         <file alias="machine_16px_x3.png">images/x3/machine_16px_x3.png</file>
         <file alias="machine_24px_x3.png">images/x3/machine_24px_x3.png</file>
Index: /trunk/src/VBox/Frontends/VirtualBox/VirtualBox1_x4.qrc
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/VirtualBox1_x4.qrc	(revision 75423)
+++ /trunk/src/VBox/Frontends/VirtualBox/VirtualBox1_x4.qrc	(revision 75424)
@@ -251,6 +251,6 @@
         <file alias="log_viewer_search_backward_16px_x4.png">images/x4/log_viewer_search_backward_16px_x4.png</file>
         <file alias="log_viewer_search_forward_16px_x4.png">images/x4/log_viewer_search_forward_16px_x4.png</file>
-        <file alias="log_viewer_settings_32px_x4.png">images/x4/log_viewer_settings_32px_x4.png</file>
-        <file alias="log_viewer_settings_disabled_32px_x4.png">images/x4/log_viewer_settings_disabled_32px_x4.png</file>
+        <file alias="log_viewer_options_32px_x4.png">images/x4/log_viewer_options_32px_x4.png</file>
+        <file alias="log_viewer_options_disabled_32px_x4.png">images/x4/log_viewer_options_disabled_32px_x4.png</file>
         <file alias="machine_16px_x4.png">images/x4/machine_16px_x4.png</file>
         <file alias="machine_24px_x4.png">images/x4/machine_24px_x4.png</file>
Index: /trunk/src/VBox/Frontends/VirtualBox/src/extradata/UIExtraDataDefs.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/extradata/UIExtraDataDefs.cpp	(revision 75423)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/extradata/UIExtraDataDefs.cpp	(revision 75424)
@@ -218,5 +218,5 @@
 /* Virtual Machine: Log-viewer: */
 const char *UIExtraDataDefs::GUI_LogWindowGeometry = "GUI/LogWindowGeometry";
-const char *UIExtraDataDefs::GUI_LogViewerSettings = "GUI/LogViewerSettings";
+const char *UIExtraDataDefs::GUI_LogViewerOptions = "GUI/LogViewerOptions";
 const char *UIExtraDataDefs::GUI_LogViewerWrapLinesEnabled = "WrapLines";
 const char *UIExtraDataDefs::GUI_LogViewerShowLineNumbersDisabled = "showLineNumbersDisabled";
Index: /trunk/src/VBox/Frontends/VirtualBox/src/extradata/UIExtraDataManager.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/extradata/UIExtraDataManager.cpp	(revision 75423)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/extradata/UIExtraDataManager.cpp	(revision 75424)
@@ -4494,5 +4494,5 @@
 }
 
-void UIExtraDataManager::setLogViweverSettings(const QFont &font, bool wrapLines, bool showLineNumbers)
+void UIExtraDataManager::setLogViweverOptions(const QFont &font, bool wrapLines, bool showLineNumbers)
 {
     /* Serialize passed values: */
@@ -4513,10 +4513,10 @@
 
     /* Re-cache corresponding extra-data: */
-    setExtraDataStringList(GUI_LogViewerSettings, data);
+    setExtraDataStringList(GUI_LogViewerOptions, data);
 }
 
 bool UIExtraDataManager::logViewerWrapLines()
 {
-    const QStringList data = extraDataStringList(GUI_LogViewerSettings);
+    const QStringList data = extraDataStringList(GUI_LogViewerOptions);
     for (int i = 0; i < data.size(); ++i)
     {
@@ -4529,5 +4529,5 @@
 bool UIExtraDataManager::logViewerShowLineNumbers()
 {
-    const QStringList data = extraDataStringList(GUI_LogViewerSettings);
+    const QStringList data = extraDataStringList(GUI_LogViewerOptions);
     for (int i = 0; i < data.size(); ++i)
     {
@@ -4540,5 +4540,5 @@
 QFont UIExtraDataManager::logViewerFont()
 {
-    const QStringList data = extraDataStringList(GUI_LogViewerSettings);
+    const QStringList data = extraDataStringList(GUI_LogViewerOptions);
     if (data.size() < 3)
         return QFont();
Index: /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIActionPool.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIActionPool.h	(revision 75423)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIActionPool.h	(revision 75424)
@@ -94,5 +94,5 @@
     UIActionIndex_M_Log_T_Filter,
     UIActionIndex_M_Log_T_Bookmark,
-    UIActionIndex_M_Log_T_Settings,
+    UIActionIndex_M_Log_T_Options,
     UIActionIndex_M_Log_S_Refresh,
     UIActionIndex_M_Log_S_Save,
Index: /trunk/src/VBox/Frontends/VirtualBox/src/logviewer/UIVMLogViewerOptionsPanel.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/logviewer/UIVMLogViewerOptionsPanel.cpp	(revision 75424)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/logviewer/UIVMLogViewerOptionsPanel.cpp	(revision 75424)
@@ -0,0 +1,193 @@
+/* $Id$ */
+/** @file
+ * VBox Qt GUI - UIVMLogViewer class implementation.
+ */
+
+/*
+ * Copyright (C) 2010-2017 Oracle Corporation
+ *
+ * This file is part of VirtualBox Open Source Edition (OSE), as
+ * available from http://www.virtualbox.org. This file is free software;
+ * you can redistribute it and/or modify it under the terms of the GNU
+ * General Public License (GPL) as published by the Free Software
+ * Foundation, in version 2 as it comes in the "COPYING" file of the
+ * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
+ * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
+ */
+
+#ifdef VBOX_WITH_PRECOMPILED_HEADERS
+# include <precomp.h>
+#else  /* !VBOX_WITH_PRECOMPILED_HEADERS */
+
+/* Qt includes: */
+# include <QComboBox>
+# include <QHBoxLayout>
+# include <QFontDatabase>
+# include <QFontDialog>
+# include <QCheckBox>
+# include <QLabel>
+# include <QSpinBox>
+
+/* GUI includes: */
+# include "QIToolButton.h"
+# include "UIIconPool.h"
+# include "UIVMLogViewerOptionsPanel.h"
+# include "UIVMLogViewerWidget.h"
+
+#endif /* !VBOX_WITH_PRECOMPILED_HEADERS */
+
+
+UIVMLogViewerOptionsPanel::UIVMLogViewerOptionsPanel(QWidget *pParent, UIVMLogViewerWidget *pViewer)
+    : UIVMLogViewerPanel(pParent, pViewer)
+    , m_pLineNumberCheckBox(0)
+    , m_pWrapLinesCheckBox(0)
+    , m_pFontSizeSpinBox(0)
+    , m_pFontSizeLabel(0)
+    , m_pOpenFontDialogButton(0)
+    , m_pResetToDefaultsButton(0)
+    , m_iDefaultFontSize(9)
+{
+    prepare();
+}
+
+void UIVMLogViewerOptionsPanel::setShowLineNumbers(bool bShowLineNumbers)
+{
+    if (!m_pLineNumberCheckBox)
+        return;
+    if (m_pLineNumberCheckBox->isChecked() == bShowLineNumbers)
+        return;
+    m_pLineNumberCheckBox->setChecked(bShowLineNumbers);
+}
+
+void UIVMLogViewerOptionsPanel::setWrapLines(bool bWrapLines)
+{
+    if (!m_pWrapLinesCheckBox)
+        return;
+    if (m_pWrapLinesCheckBox->isChecked() == bWrapLines)
+        return;
+    m_pWrapLinesCheckBox->setChecked(bWrapLines);
+}
+
+void UIVMLogViewerOptionsPanel::setFontSizeInPoints(int fontSizeInPoints)
+{
+    if (!m_pFontSizeSpinBox)
+        return;
+    if (m_pFontSizeSpinBox->value() == fontSizeInPoints)
+        return;
+    m_pFontSizeSpinBox->setValue(fontSizeInPoints);
+}
+
+void UIVMLogViewerOptionsPanel::prepareWidgets()
+{
+    if (!mainLayout())
+        return;
+
+    /* Create line-number check-box: */
+    m_pLineNumberCheckBox = new QCheckBox;
+    if (m_pLineNumberCheckBox)
+    {
+        m_pLineNumberCheckBox->setChecked(true);
+        mainLayout()->addWidget(m_pLineNumberCheckBox, 0, Qt::AlignLeft);
+    }
+
+    /* Create wrap-lines check-box: */
+    m_pWrapLinesCheckBox = new QCheckBox;
+    if (m_pWrapLinesCheckBox)
+    {
+        m_pWrapLinesCheckBox->setChecked(false);
+        mainLayout()->addWidget(m_pWrapLinesCheckBox, 0, Qt::AlignLeft);
+    }
+
+    /* Create font-size spin-box: */
+    m_pFontSizeSpinBox = new QSpinBox;
+    if (m_pFontSizeSpinBox)
+    {
+        mainLayout()->addWidget(m_pFontSizeSpinBox, 0, Qt::AlignLeft);
+        m_pFontSizeSpinBox->setValue(m_iDefaultFontSize);
+        m_pFontSizeSpinBox->setMaximum(44);
+        m_pFontSizeSpinBox->setMinimum(6);
+    }
+
+    /* Create font-size label: */
+    m_pFontSizeLabel = new QLabel;
+    if (m_pFontSizeLabel)
+    {
+        mainLayout()->addWidget(m_pFontSizeLabel, 0, Qt::AlignLeft);
+    }
+
+    /* Create combo/button layout: */
+    QHBoxLayout *pButtonLayout = new QHBoxLayout;
+    if (pButtonLayout)
+    {
+        pButtonLayout->setContentsMargins(0, 0, 0, 0);
+        pButtonLayout->setSpacing(0);
+
+        /* Create open font dialog button: */
+        m_pOpenFontDialogButton = new QIToolButton;
+        if (m_pOpenFontDialogButton)
+        {
+            pButtonLayout->addWidget(m_pOpenFontDialogButton, 0);
+            m_pOpenFontDialogButton->setIcon(UIIconPool::iconSet(":/log_viewer_choose_font_16px.png"));
+        }
+
+        /* Create reset font to default button: */
+        m_pResetToDefaultsButton = new QIToolButton;
+        if (m_pResetToDefaultsButton)
+        {
+            pButtonLayout->addWidget(m_pResetToDefaultsButton, 0);
+            m_pResetToDefaultsButton->setIcon(UIIconPool::iconSet(":/log_viewer_reset_font_16px.png"));
+        }
+
+        mainLayout()->addLayout(pButtonLayout);
+    }
+
+    mainLayout()->addStretch(2);
+}
+
+void UIVMLogViewerOptionsPanel::prepareConnections()
+{
+    if (m_pLineNumberCheckBox)
+        connect(m_pLineNumberCheckBox, &QCheckBox::toggled, this, &UIVMLogViewerOptionsPanel::sigShowLineNumbers);
+    if (m_pWrapLinesCheckBox)
+        connect(m_pWrapLinesCheckBox, &QCheckBox::toggled, this, &UIVMLogViewerOptionsPanel::sigWrapLines);
+    if (m_pFontSizeSpinBox)
+        connect(m_pFontSizeSpinBox, static_cast<void(QSpinBox::*)(int)>(&QSpinBox::valueChanged),
+                this, &UIVMLogViewerOptionsPanel::sigChangeFontSizeInPoints);
+    if (m_pOpenFontDialogButton)
+        connect(m_pOpenFontDialogButton, &QIToolButton::clicked, this, &UIVMLogViewerOptionsPanel::sltOpenFontDialog);
+    if (m_pResetToDefaultsButton)
+        connect(m_pResetToDefaultsButton, &QIToolButton::clicked, this, &UIVMLogViewerOptionsPanel::sigResetToDefaults);
+}
+
+void UIVMLogViewerOptionsPanel::retranslateUi()
+{
+    UIVMLogViewerPanel::retranslateUi();
+
+    m_pLineNumberCheckBox->setText(UIVMLogViewerWidget::tr("Show Line Numbers"));
+    m_pLineNumberCheckBox->setToolTip(UIVMLogViewerWidget::tr("When checked, show line numbers"));
+
+    m_pWrapLinesCheckBox->setText(UIVMLogViewerWidget::tr("Wrap Lines"));
+    m_pWrapLinesCheckBox->setToolTip(UIVMLogViewerWidget::tr("When checked, wrap lines"));
+
+    m_pFontSizeLabel->setText(UIVMLogViewerWidget::tr("Font Size"));
+    m_pFontSizeSpinBox->setToolTip(UIVMLogViewerWidget::tr("Log viewer font size"));
+
+    m_pOpenFontDialogButton->setToolTip(UIVMLogViewerWidget::tr("Open a font dialog to select font face for the logviewer"));
+    m_pResetToDefaultsButton->setToolTip(UIVMLogViewerWidget::tr("Reset options to application defaults"));
+}
+
+void UIVMLogViewerOptionsPanel::sltOpenFontDialog()
+{
+    QFont currentFont;
+    UIVMLogViewerWidget* parentWidget = qobject_cast<UIVMLogViewerWidget*>(parent());
+    if (!parentWidget)
+        return;
+
+    currentFont = parentWidget->currentFont();
+    bool ok;
+    QFont font =
+        QFontDialog::getFont(&ok, currentFont, this, "Logviewer font");
+
+    if (ok)
+        emit sigChangeFont(font);
+}
Index: /trunk/src/VBox/Frontends/VirtualBox/src/logviewer/UIVMLogViewerOptionsPanel.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/logviewer/UIVMLogViewerOptionsPanel.h	(revision 75424)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/logviewer/UIVMLogViewerOptionsPanel.h	(revision 75424)
@@ -0,0 +1,81 @@
+/* $Id$ */
+/** @file
+ * VBox Qt GUI - UIVMLogViewer class declaration.
+ */
+
+/*
+ * Copyright (C) 2010-2017 Oracle Corporation
+ *
+ * This file is part of VirtualBox Open Source Edition (OSE), as
+ * available from http://www.virtualbox.org. This file is free software;
+ * you can redistribute it and/or modify it under the terms of the GNU
+ * General Public License (GPL) as published by the Free Software
+ * Foundation, in version 2 as it comes in the "COPYING" file of the
+ * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
+ * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
+ */
+
+#ifndef ___UIVMLogViewerOptionsPanel_h___
+#define ___UIVMLogViewerOptionsPanel_h___
+
+/* GUI includes: */
+#include "UIVMLogViewerPanel.h"
+
+/* Forward declarations: */
+class QCheckBox;
+class QSpinBox;
+class QLabel;
+class QIToolButton;
+class UIVMLogViewerWidget;
+
+/** UIVMLogViewerPanel extension providing GUI to manage logviewer options. */
+class UIVMLogViewerOptionsPanel : public UIVMLogViewerPanel
+{
+    Q_OBJECT;
+
+signals:
+
+    void sigShowLineNumbers(bool show);
+    void sigWrapLines(bool show);
+    void sigChangeFontSizeInPoints(int size);
+    void sigChangeFont(QFont font);
+    void sigResetToDefaults();
+
+public:
+
+    UIVMLogViewerOptionsPanel(QWidget *pParent, UIVMLogViewerWidget *pViewer);
+
+    void setShowLineNumbers(bool bShowLineNumbers);
+    void setWrapLines(bool bWrapLines);
+    void setFontSizeInPoints(int fontSizeInPoints);
+
+public slots:
+
+
+protected:
+
+    virtual void prepareWidgets() /* override */;
+    virtual void prepareConnections() /* override */;
+
+    /** Handles the translation event. */
+    void retranslateUi();
+
+private slots:
+
+    void sltOpenFontDialog();
+
+private:
+
+    QCheckBox    *m_pLineNumberCheckBox;
+    QCheckBox    *m_pWrapLinesCheckBox;
+    QSpinBox     *m_pFontSizeSpinBox;
+    QLabel       *m_pFontSizeLabel;
+    QIToolButton *m_pOpenFontDialogButton;
+    QIToolButton *m_pResetToDefaultsButton;
+
+    /** Default font size in points. */
+    const int    m_iDefaultFontSize;
+
+};
+
+#endif /* !___UIVMLogViewerOptionsPanel_h___ */
Index: unk/src/VBox/Frontends/VirtualBox/src/logviewer/UIVMLogViewerSettingsPanel.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/logviewer/UIVMLogViewerSettingsPanel.cpp	(revision 75423)
+++ 	(revision )
@@ -1,193 +1,0 @@
-/* $Id$ */
-/** @file
- * VBox Qt GUI - UIVMLogViewer class implementation.
- */
-
-/*
- * Copyright (C) 2010-2017 Oracle Corporation
- *
- * This file is part of VirtualBox Open Source Edition (OSE), as
- * available from http://www.virtualbox.org. This file is free software;
- * you can redistribute it and/or modify it under the terms of the GNU
- * General Public License (GPL) as published by the Free Software
- * Foundation, in version 2 as it comes in the "COPYING" file of the
- * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
- * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
- */
-
-#ifdef VBOX_WITH_PRECOMPILED_HEADERS
-# include <precomp.h>
-#else  /* !VBOX_WITH_PRECOMPILED_HEADERS */
-
-/* Qt includes: */
-# include <QComboBox>
-# include <QHBoxLayout>
-# include <QFontDatabase>
-# include <QFontDialog>
-# include <QCheckBox>
-# include <QLabel>
-# include <QSpinBox>
-
-/* GUI includes: */
-# include "QIToolButton.h"
-# include "UIIconPool.h"
-# include "UIVMLogViewerSettingsPanel.h"
-# include "UIVMLogViewerWidget.h"
-
-#endif /* !VBOX_WITH_PRECOMPILED_HEADERS */
-
-
-UIVMLogViewerSettingsPanel::UIVMLogViewerSettingsPanel(QWidget *pParent, UIVMLogViewerWidget *pViewer)
-    : UIVMLogViewerPanel(pParent, pViewer)
-    , m_pLineNumberCheckBox(0)
-    , m_pWrapLinesCheckBox(0)
-    , m_pFontSizeSpinBox(0)
-    , m_pFontSizeLabel(0)
-    , m_pOpenFontDialogButton(0)
-    , m_pResetToDefaultsButton(0)
-    , m_iDefaultFontSize(9)
-{
-    prepare();
-}
-
-void UIVMLogViewerSettingsPanel::setShowLineNumbers(bool bShowLineNumbers)
-{
-    if (!m_pLineNumberCheckBox)
-        return;
-    if (m_pLineNumberCheckBox->isChecked() == bShowLineNumbers)
-        return;
-    m_pLineNumberCheckBox->setChecked(bShowLineNumbers);
-}
-
-void UIVMLogViewerSettingsPanel::setWrapLines(bool bWrapLines)
-{
-    if (!m_pWrapLinesCheckBox)
-        return;
-    if (m_pWrapLinesCheckBox->isChecked() == bWrapLines)
-        return;
-    m_pWrapLinesCheckBox->setChecked(bWrapLines);
-}
-
-void UIVMLogViewerSettingsPanel::setFontSizeInPoints(int fontSizeInPoints)
-{
-    if (!m_pFontSizeSpinBox)
-        return;
-    if (m_pFontSizeSpinBox->value() == fontSizeInPoints)
-        return;
-    m_pFontSizeSpinBox->setValue(fontSizeInPoints);
-}
-
-void UIVMLogViewerSettingsPanel::prepareWidgets()
-{
-    if (!mainLayout())
-        return;
-
-    /* Create line-number check-box: */
-    m_pLineNumberCheckBox = new QCheckBox;
-    if (m_pLineNumberCheckBox)
-    {
-        m_pLineNumberCheckBox->setChecked(true);
-        mainLayout()->addWidget(m_pLineNumberCheckBox, 0, Qt::AlignLeft);
-    }
-
-    /* Create wrap-lines check-box: */
-    m_pWrapLinesCheckBox = new QCheckBox;
-    if (m_pWrapLinesCheckBox)
-    {
-        m_pWrapLinesCheckBox->setChecked(false);
-        mainLayout()->addWidget(m_pWrapLinesCheckBox, 0, Qt::AlignLeft);
-    }
-
-    /* Create font-size spin-box: */
-    m_pFontSizeSpinBox = new QSpinBox;
-    if (m_pFontSizeSpinBox)
-    {
-        mainLayout()->addWidget(m_pFontSizeSpinBox, 0, Qt::AlignLeft);
-        m_pFontSizeSpinBox->setValue(m_iDefaultFontSize);
-        m_pFontSizeSpinBox->setMaximum(44);
-        m_pFontSizeSpinBox->setMinimum(6);
-    }
-
-    /* Create font-size label: */
-    m_pFontSizeLabel = new QLabel;
-    if (m_pFontSizeLabel)
-    {
-        mainLayout()->addWidget(m_pFontSizeLabel, 0, Qt::AlignLeft);
-    }
-
-    /* Create combo/button layout: */
-    QHBoxLayout *pButtonLayout = new QHBoxLayout;
-    if (pButtonLayout)
-    {
-        pButtonLayout->setContentsMargins(0, 0, 0, 0);
-        pButtonLayout->setSpacing(0);
-
-        /* Create open font dialog button: */
-        m_pOpenFontDialogButton = new QIToolButton;
-        if (m_pOpenFontDialogButton)
-        {
-            pButtonLayout->addWidget(m_pOpenFontDialogButton, 0);
-            m_pOpenFontDialogButton->setIcon(UIIconPool::iconSet(":/log_viewer_choose_font_16px.png"));
-        }
-
-        /* Create reset font to default button: */
-        m_pResetToDefaultsButton = new QIToolButton;
-        if (m_pResetToDefaultsButton)
-        {
-            pButtonLayout->addWidget(m_pResetToDefaultsButton, 0);
-            m_pResetToDefaultsButton->setIcon(UIIconPool::iconSet(":/log_viewer_reset_font_16px.png"));
-        }
-
-        mainLayout()->addLayout(pButtonLayout);
-    }
-
-    mainLayout()->addStretch(2);
-}
-
-void UIVMLogViewerSettingsPanel::prepareConnections()
-{
-    if (m_pLineNumberCheckBox)
-        connect(m_pLineNumberCheckBox, &QCheckBox::toggled, this, &UIVMLogViewerSettingsPanel::sigShowLineNumbers);
-    if (m_pWrapLinesCheckBox)
-        connect(m_pWrapLinesCheckBox, &QCheckBox::toggled, this, &UIVMLogViewerSettingsPanel::sigWrapLines);
-    if (m_pFontSizeSpinBox)
-        connect(m_pFontSizeSpinBox, static_cast<void(QSpinBox::*)(int)>(&QSpinBox::valueChanged),
-                this, &UIVMLogViewerSettingsPanel::sigChangeFontSizeInPoints);
-    if (m_pOpenFontDialogButton)
-        connect(m_pOpenFontDialogButton, &QIToolButton::clicked, this, &UIVMLogViewerSettingsPanel::sltOpenFontDialog);
-    if (m_pResetToDefaultsButton)
-        connect(m_pResetToDefaultsButton, &QIToolButton::clicked, this, &UIVMLogViewerSettingsPanel::sigResetToDefaults);
-}
-
-void UIVMLogViewerSettingsPanel::retranslateUi()
-{
-    UIVMLogViewerPanel::retranslateUi();
-
-    m_pLineNumberCheckBox->setText(UIVMLogViewerWidget::tr("Show Line Numbers"));
-    m_pLineNumberCheckBox->setToolTip(UIVMLogViewerWidget::tr("When checked, show line numbers"));
-
-    m_pWrapLinesCheckBox->setText(UIVMLogViewerWidget::tr("Wrap Lines"));
-    m_pWrapLinesCheckBox->setToolTip(UIVMLogViewerWidget::tr("When checked, wrap lines"));
-
-    m_pFontSizeLabel->setText(UIVMLogViewerWidget::tr("Font Size"));
-    m_pFontSizeSpinBox->setToolTip(UIVMLogViewerWidget::tr("Log viewer font size"));
-
-    m_pOpenFontDialogButton->setToolTip(UIVMLogViewerWidget::tr("Open a font dialog to select font face for the logviewer"));
-    m_pResetToDefaultsButton->setToolTip(UIVMLogViewerWidget::tr("Reset settings to application defaults"));
-}
-
-void UIVMLogViewerSettingsPanel::sltOpenFontDialog()
-{
-    QFont currentFont;
-    UIVMLogViewerWidget* parentWidget = qobject_cast<UIVMLogViewerWidget*>(parent());
-    if (!parentWidget)
-        return;
-
-    currentFont = parentWidget->currentFont();
-    bool ok;
-    QFont font =
-        QFontDialog::getFont(&ok, currentFont, this, "Logviewer font");
-
-    if (ok)
-        emit sigChangeFont(font);
-}
Index: unk/src/VBox/Frontends/VirtualBox/src/logviewer/UIVMLogViewerSettingsPanel.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/logviewer/UIVMLogViewerSettingsPanel.h	(revision 75423)
+++ 	(revision )
@@ -1,81 +1,0 @@
-/* $Id$ */
-/** @file
- * VBox Qt GUI - UIVMLogViewer class declaration.
- */
-
-/*
- * Copyright (C) 2010-2017 Oracle Corporation
- *
- * This file is part of VirtualBox Open Source Edition (OSE), as
- * available from http://www.virtualbox.org. This file is free software;
- * you can redistribute it and/or modify it under the terms of the GNU
- * General Public License (GPL) as published by the Free Software
- * Foundation, in version 2 as it comes in the "COPYING" file of the
- * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
- * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
- */
-
-#ifndef ___UIVMLogViewerSettingssPanel_h___
-#define ___UIVMLogViewerSettingssPanel_h___
-
-/* GUI includes: */
-#include "UIVMLogViewerPanel.h"
-
-/* Forward declarations: */
-class QCheckBox;
-class QSpinBox;
-class QLabel;
-class QIToolButton;
-class UIVMLogViewerWidget;
-
-/** UIVMLogViewerPanel extension providing GUI to manage logviewer settings. */
-class UIVMLogViewerSettingsPanel : public UIVMLogViewerPanel
-{
-    Q_OBJECT;
-
-signals:
-
-    void sigShowLineNumbers(bool show);
-    void sigWrapLines(bool show);
-    void sigChangeFontSizeInPoints(int size);
-    void sigChangeFont(QFont font);
-    void sigResetToDefaults();
-
-public:
-
-    UIVMLogViewerSettingsPanel(QWidget *pParent, UIVMLogViewerWidget *pViewer);
-
-    void setShowLineNumbers(bool bShowLineNumbers);
-    void setWrapLines(bool bWrapLines);
-    void setFontSizeInPoints(int fontSizeInPoints);
-
-public slots:
-
-
-protected:
-
-    virtual void prepareWidgets() /* override */;
-    virtual void prepareConnections() /* override */;
-
-    /** Handles the translation event. */
-    void retranslateUi();
-
-private slots:
-
-    void sltOpenFontDialog();
-
-private:
-
-    QCheckBox    *m_pLineNumberCheckBox;
-    QCheckBox    *m_pWrapLinesCheckBox;
-    QSpinBox     *m_pFontSizeSpinBox;
-    QLabel       *m_pFontSizeLabel;
-    QIToolButton *m_pOpenFontDialogButton;
-    QIToolButton *m_pResetToDefaultsButton;
-
-    /** Default font size in points. */
-    const int    m_iDefaultFontSize;
-
-};
-
-#endif /* !___UIVMLogViewerSettingsPanel_h___ */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/logviewer/UIVMLogViewerWidget.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/logviewer/UIVMLogViewerWidget.cpp	(revision 75423)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/logviewer/UIVMLogViewerWidget.cpp	(revision 75424)
@@ -47,5 +47,5 @@
 # include "UIVMLogViewerFilterPanel.h"
 # include "UIVMLogViewerSearchPanel.h"
-# include "UIVMLogViewerSettingsPanel.h"
+# include "UIVMLogViewerOptionsPanel.h"
 # include "UIToolBar.h"
 
@@ -73,5 +73,5 @@
     , m_pFilterPanel(0)
     , m_pBookmarksPanel(0)
-    , m_pSettingsPanel(0)
+    , m_pOptionsPanel(0)
     , m_pMainLayout(0)
     , m_pToolBar(0)
@@ -194,5 +194,5 @@
     m_pActionPool->action(UIActionIndex_M_Log_S_Save)->setEnabled(!noLogsToShow);
     m_pActionPool->action(UIActionIndex_M_Log_T_Bookmark)->setEnabled(!noLogsToShow);
-    m_pActionPool->action(UIActionIndex_M_Log_T_Settings)->setEnabled(!noLogsToShow);
+    m_pActionPool->action(UIActionIndex_M_Log_T_Options)->setEnabled(!noLogsToShow);
 
     m_pTabWidget->show();
@@ -402,5 +402,5 @@
 }
 
-void UIVMLogViewerWidget::sltResetSettingsToDefault()
+void UIVMLogViewerWidget::sltResetOptionsToDefault()
 {
     sltShowLineNumbers(true);
@@ -408,9 +408,9 @@
     sltChangeFont(QFontDatabase::systemFont(QFontDatabase::FixedFont));
 
-    if (m_pSettingsPanel)
-    {
-        m_pSettingsPanel->setShowLineNumbers(true);
-        m_pSettingsPanel->setWrapLines(false);
-        m_pSettingsPanel->setFontSizeInPoints(m_font.pointSize());
+    if (m_pOptionsPanel)
+    {
+        m_pOptionsPanel->setShowLineNumbers(true);
+        m_pOptionsPanel->setWrapLines(false);
+        m_pOptionsPanel->setFontSizeInPoints(m_font.pointSize());
     }
 }
@@ -422,6 +422,6 @@
     /* Prepare widgets: */
     prepareWidgets();
-    /* Load settings: */
-    loadSettings();
+    /* Load options: */
+    loadOptions();
 
     /* Apply language settings: */
@@ -440,5 +440,5 @@
     addAction(m_pActionPool->action(UIActionIndex_M_Log_T_Filter));
     addAction(m_pActionPool->action(UIActionIndex_M_Log_T_Bookmark));
-    addAction(m_pActionPool->action(UIActionIndex_M_Log_T_Settings));
+    addAction(m_pActionPool->action(UIActionIndex_M_Log_T_Options));
     addAction(m_pActionPool->action(UIActionIndex_M_Log_S_Refresh));
     addAction(m_pActionPool->action(UIActionIndex_M_Log_S_Save));
@@ -451,5 +451,5 @@
     connect(m_pActionPool->action(UIActionIndex_M_Log_T_Bookmark), &QAction::toggled,
             this, &UIVMLogViewerWidget::sltPanelActionToggled);
-    connect(m_pActionPool->action(UIActionIndex_M_Log_T_Settings), &QAction::toggled,
+    connect(m_pActionPool->action(UIActionIndex_M_Log_T_Options), &QAction::toggled,
             this, &UIVMLogViewerWidget::sltPanelActionToggled);
     connect(m_pActionPool->action(UIActionIndex_M_Log_S_Refresh), &QAction::triggered,
@@ -533,22 +533,22 @@
         }
 
-        /* Create VM Log-Viewer settings-panel: */
-        m_pSettingsPanel = new UIVMLogViewerSettingsPanel(0, this);
-        if (m_pSettingsPanel)
+        /* Create VM Log-Viewer options-panel: */
+        m_pOptionsPanel = new UIVMLogViewerOptionsPanel(0, this);
+        if (m_pOptionsPanel)
         {
             /* Configure panel: */
-            m_pSettingsPanel->hide();
-            m_pSettingsPanel->setShowLineNumbers(m_bShowLineNumbers);
-            m_pSettingsPanel->setWrapLines(m_bWrapLines);
-            m_pSettingsPanel->setFontSizeInPoints(m_font.pointSize());
-            connect(m_pSettingsPanel, &UIVMLogViewerSettingsPanel::sigShowLineNumbers, this, &UIVMLogViewerWidget::sltShowLineNumbers);
-            connect(m_pSettingsPanel, &UIVMLogViewerSettingsPanel::sigWrapLines, this, &UIVMLogViewerWidget::sltWrapLines);
-            connect(m_pSettingsPanel, &UIVMLogViewerSettingsPanel::sigChangeFontSizeInPoints, this, &UIVMLogViewerWidget::sltFontSizeChanged);
-            connect(m_pSettingsPanel, &UIVMLogViewerSettingsPanel::sigChangeFont, this, &UIVMLogViewerWidget::sltChangeFont);
-            connect(m_pSettingsPanel, &UIVMLogViewerSettingsPanel::sigResetToDefaults, this, &UIVMLogViewerWidget::sltResetSettingsToDefault);
-            m_panelActionMap.insert(m_pSettingsPanel, m_pActionPool->action(UIActionIndex_M_Log_T_Settings));
+            m_pOptionsPanel->hide();
+            m_pOptionsPanel->setShowLineNumbers(m_bShowLineNumbers);
+            m_pOptionsPanel->setWrapLines(m_bWrapLines);
+            m_pOptionsPanel->setFontSizeInPoints(m_font.pointSize());
+            connect(m_pOptionsPanel, &UIVMLogViewerOptionsPanel::sigShowLineNumbers, this, &UIVMLogViewerWidget::sltShowLineNumbers);
+            connect(m_pOptionsPanel, &UIVMLogViewerOptionsPanel::sigWrapLines, this, &UIVMLogViewerWidget::sltWrapLines);
+            connect(m_pOptionsPanel, &UIVMLogViewerOptionsPanel::sigChangeFontSizeInPoints, this, &UIVMLogViewerWidget::sltFontSizeChanged);
+            connect(m_pOptionsPanel, &UIVMLogViewerOptionsPanel::sigChangeFont, this, &UIVMLogViewerWidget::sltChangeFont);
+            connect(m_pOptionsPanel, &UIVMLogViewerOptionsPanel::sigResetToDefaults, this, &UIVMLogViewerWidget::sltResetOptionsToDefault);
+            m_panelActionMap.insert(m_pOptionsPanel, m_pActionPool->action(UIActionIndex_M_Log_T_Options));
 
             /* Add into layout: */
-            m_pMainLayout->addWidget(m_pSettingsPanel);
+            m_pMainLayout->addWidget(m_pOptionsPanel);
         }
     }
@@ -572,5 +572,5 @@
         m_pToolBar->addAction(m_pActionPool->action(UIActionIndex_M_Log_T_Filter));
         m_pToolBar->addAction(m_pActionPool->action(UIActionIndex_M_Log_T_Bookmark));
-        m_pToolBar->addAction(m_pActionPool->action(UIActionIndex_M_Log_T_Settings));
+        m_pToolBar->addAction(m_pActionPool->action(UIActionIndex_M_Log_T_Options));
         m_pToolBar->addSeparator();
         m_pToolBar->addAction(m_pActionPool->action(UIActionIndex_M_Log_S_Refresh));
@@ -590,5 +590,5 @@
 }
 
-void UIVMLogViewerWidget::loadSettings()
+void UIVMLogViewerWidget::loadOptions()
 {
     m_bWrapLines = gEDataManager->logViewerWrapLines();
@@ -599,13 +599,13 @@
 }
 
-void UIVMLogViewerWidget::saveSettings()
-{
-    gEDataManager->setLogViweverSettings(m_font, m_bWrapLines, m_bShowLineNumbers);
+void UIVMLogViewerWidget::saveOptions()
+{
+    gEDataManager->setLogViweverOptions(m_font, m_bWrapLines, m_bShowLineNumbers);
 }
 
 void UIVMLogViewerWidget::cleanup()
 {
-    /* Save settings: */
-    saveSettings();
+    /* Save options: */
+    saveOptions();
 }
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/UIVirtualBoxManagerWidget.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/UIVirtualBoxManagerWidget.cpp	(revision 75423)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/UIVirtualBoxManagerWidget.cpp	(revision 75424)
@@ -682,5 +682,5 @@
                     m_pToolBar->addAction(actionPool()->action(UIActionIndex_M_Log_T_Filter));
                     m_pToolBar->addAction(actionPool()->action(UIActionIndex_M_Log_T_Bookmark));
-                    m_pToolBar->addAction(actionPool()->action(UIActionIndex_M_Log_T_Settings));
+                    m_pToolBar->addAction(actionPool()->action(UIActionIndex_M_Log_T_Options));
                     m_pToolBar->addAction(actionPool()->action(UIActionIndex_M_Log_S_Refresh));
                     m_pToolBar->addSeparator();

Index: /trunk/src/VBox/Frontends/VirtualBox/src/extradata/UIExtraDataDefs.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/extradata/UIExtraDataDefs.h	(revision 75423)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/extradata/UIExtraDataDefs.h	(revision 75424)
@@ -392,7 +392,7 @@
         SHARED_LIBRARY_STUFF extern const char *GUI_LogWindowGeometry;
     /** @} */
-    /** @name Virtual Machine: Log-viewer widget settings
-      * @{ */
-        SHARED_LIBRARY_STUFF extern const char *GUI_LogViewerSettings;
+    /** @name Virtual Machine: Log-viewer widget options
+      * @{ */
+        SHARED_LIBRARY_STUFF extern const char *GUI_LogViewerOptions;
         /** Holds log-viewer wrap line flag. */
         SHARED_LIBRARY_STUFF extern const char *GUI_LogViewerWrapLinesEnabled;
Index: /trunk/src/VBox/Frontends/VirtualBox/src/extradata/UIExtraDataManager.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/extradata/UIExtraDataManager.h	(revision 75423)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/extradata/UIExtraDataManager.h	(revision 75424)
@@ -689,7 +689,7 @@
     /** @} */
 
-    /** @name Virtual Machine: Log Viewer widget settings
-      * @{ */
-        void setLogViweverSettings(const QFont &font, bool wrapLines, bool showLineNumbers);
+    /** @name Virtual Machine: Log Viewer widget options
+      * @{ */
+        void setLogViweverOptions(const QFont &font, bool wrapLines, bool showLineNumbers);
         /** Returns log-viewer line wrapping flag. */
         bool logViewerWrapLines();
Index: /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIActionPool.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIActionPool.cpp	(revision 75423)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIActionPool.cpp	(revision 75424)
@@ -1332,26 +1332,26 @@
 };
 
-/** Simple action extension, used as 'Toggle Pane Settings' action class. */
-class UIActionMenuSelectorLogTogglePaneSettings : public UIActionToggle
-{
-    Q_OBJECT;
-
-public:
-
-    /** Constructs action passing @a pParent to the base-class. */
-    UIActionMenuSelectorLogTogglePaneSettings(UIActionPool *pParent)
+/** Simple action extension, used as 'Toggle Pane Options' action class. */
+class UIActionMenuSelectorLogTogglePaneOptions : public UIActionToggle
+{
+    Q_OBJECT;
+
+public:
+
+    /** Constructs action passing @a pParent to the base-class. */
+    UIActionMenuSelectorLogTogglePaneOptions(UIActionPool *pParent)
         : UIActionToggle(pParent)
     {
         setShortcutContext(Qt::WidgetWithChildrenShortcut);
-        setIcon(UIIconPool::iconSetFull(":/log_viewer_settings_32px.png",          ":/log_viewer_settings_16px.png",
-                                        ":/log_viewer_settings_disabled_32px.png", ":/log_viewer_settings_disabled_16px.png"));
-    }
-
-protected:
-
-    /** Returns shortcut extra-data ID. */
-    virtual QString shortcutExtraDataID() const /* override */
-    {
-        return QString("ToggleLogSettings");
+        setIcon(UIIconPool::iconSetFull(":/log_viewer_options_32px.png",          ":/log_viewer_options_16px.png",
+                                        ":/log_viewer_options_disabled_32px.png", ":/log_viewer_options_disabled_16px.png"));
+    }
+
+protected:
+
+    /** Returns shortcut extra-data ID. */
+    virtual QString shortcutExtraDataID() const /* override */
+    {
+        return QString("ToggleLogOptions");
     }
 
@@ -1365,8 +1365,8 @@
     virtual void retranslateUi() /* override */
     {
-        setName(QApplication::translate("UIActionPool", "&Settings"));
+        setName(QApplication::translate("UIActionPool", "&Options"));
         setShortcutScope(QApplication::translate("UIActionPool", "Log Viewer"));
-        setStatusTip(QApplication::translate("UIActionPool", "Open pane with log viewer settings"));
-        setToolTip(QApplication::translate("UIActionPool", "Open Settings Pane (%1)").arg(shortcut().toString()));
+        setStatusTip(QApplication::translate("UIActionPool", "Open pane with log viewer options"));
+        setToolTip(QApplication::translate("UIActionPool", "Open Options Pane (%1)").arg(shortcut().toString()));
     }
 };
@@ -2500,5 +2500,5 @@
     m_pool[UIActionIndex_M_Log_T_Filter] = new UIActionMenuSelectorLogTogglePaneFilter(this);
     m_pool[UIActionIndex_M_Log_T_Bookmark] = new UIActionMenuSelectorLogTogglePaneBookmark(this);
-    m_pool[UIActionIndex_M_Log_T_Settings] = new UIActionMenuSelectorLogTogglePaneSettings(this);
+    m_pool[UIActionIndex_M_Log_T_Options] = new UIActionMenuSelectorLogTogglePaneOptions(this);
     m_pool[UIActionIndex_M_Log_S_Refresh] = new UIActionMenuSelectorLogPerformRefresh(this);
     m_pool[UIActionIndex_M_Log_S_Save] = new UIActionMenuSelectorLogPerformSave(this);
@@ -2837,6 +2837,6 @@
     /* 'Bookmarks' action: */
     fSeparator = addAction(pMenu, action(UIActionIndex_M_Log_T_Bookmark)) || fSeparator;
-    /* 'Settings' action: */
-    fSeparator = addAction(pMenu, action(UIActionIndex_M_Log_T_Settings)) || fSeparator;
+    /* 'Options' action: */
+    fSeparator = addAction(pMenu, action(UIActionIndex_M_Log_T_Options)) || fSeparator;
 
     /* Separator? */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/logviewer/UIVMLogViewerWidget.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/logviewer/UIVMLogViewerWidget.h	(revision 75423)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/logviewer/UIVMLogViewerWidget.h	(revision 75424)
@@ -44,5 +44,5 @@
 class UIVMLogViewerPanel;
 class UIVMLogViewerSearchPanel;
-class UIVMLogViewerSettingsPanel;
+class UIVMLogViewerOptionsPanel;
 
 /** QWidget extension providing GUI for VirtualBox LogViewer. It
@@ -125,5 +125,5 @@
         void sltFontSizeChanged(int fontSize);
         void sltChangeFont(QFont font);
-        void sltResetSettingsToDefault();
+        void sltResetOptionsToDefault();
     /** @} */
 
@@ -140,9 +140,9 @@
         /** Prepares toolbar. */
         void prepareToolBar();
-        /** Loads settings.  */
-        void loadSettings();
-
-        /** Saves settings.  */
-        void saveSettings();
+        /** Loads options.  */
+        void loadOptions();
+
+        /** Saves options.  */
+        void saveOptions();
         /** Cleanups VM Log-Viewer. */
         void cleanup();
@@ -208,5 +208,5 @@
         UIVMLogViewerFilterPanel    *m_pFilterPanel;
         UIVMLogViewerBookmarksPanel *m_pBookmarksPanel;
-        UIVMLogViewerSettingsPanel  *m_pSettingsPanel;
+        UIVMLogViewerOptionsPanel  *m_pOptionsPanel;
         QMap<UIVMLogViewerPanel*, QAction*> m_panelActionMap;
         QList<UIVMLogViewerPanel*>          m_visiblePanelsList;
@@ -221,5 +221,5 @@
     /** @name Toolbar and menu variables. Cache these to restore them after refresh.
      * @{ */
         /** Showing/hiding line numbers and line wraping settings are set per
             UIVMLogViewerWidget and applies to all log pages (all tabs) */
         bool  m_bShowLineNumbers;
@@ -230,5 +230,5 @@
     friend class UIVMLogViewerFilterPanel;
     friend class UIVMLogViewerSearchPanel;
-    friend class UIVMLogViewerSettingsPanel;
+    friend class UIVMLogViewerOptionsPanel;
     friend class UIVMLogViewerPanel;
     friend class UIVMLogViewerDialog;
@@ -221,5 +221,5 @@
     /** @name Toolbar and menu variables. Cache these to restore them after refresh.
      * @{ */
-        /** Showing/hiding line numbers and line wraping settings are set per
+        /** Showing/hiding line numbers and line wraping options are set per
             UIVMLogViewerWidget and applies to all log pages (all tabs) */
         bool  m_bShowLineNumbers;